package de.fhwiesbaden.qsqs;

import org.junit.Before;
import org.junit.Test;
import static org.easymock.EasyMock.*;
import static org.junit.Assert.*;


public class MockTest{

	/* Interface fuer Mock und Klasse die das Interface nutzt*/
	private IMockMe mock;
	private MockMeImplemented piImp;
	
	/* Fuer das zu simulierende Interface wird ein Mock erzeugt */	  
	@Before
	public void  setUp(){
	
		mock = createMock(IMockMe.class);
		piImp = new MockMeImplemented();
		
	}

	/* Test ob addString mit den richtigen Parametern aufgerufen wurde,
	 * ueberprung mittels verify();, ob die Methode auch wirklich aufgerufen wurde  
	 * -> Pass*/
	@Test
	public void expectedAddSomethig(){
		
		mock.addString("i");
		replay(mock);
		piImp.addStringtoList("i", mock);
		verify(mock);
	}

	/* Test ob addString mit den richtigen Parametern aufgerufen wurde,
	 * keine ueberprung mittels verify();, ob die Methode auch wirklich aufgerufen wurde  
	 * -> Pass*/
	@Test
	public void expectedAddSomethig2(){
		
		mock.addString("i");
		replay(mock);
		
	}

	/* Test ob PI(); mit den richtigen Parametern aufgerufen wurde,
	 * mittels andReturn(); wird angegeben, welchen Wert die nicht implementierte Methode
	 * zurueckgibt.
	 * Per assertEquals wird der Rueckgabewert ueberprueft.  
	 * -> Pass*/
	@Test
	public void expectedValuePi(){
		
		expect(mock.Pi(100)).andReturn((double)3.14);
		replay(mock);
		assertEquals(3.14, piImp.returnPI(100,mock), 0);
		verify(mock);
	
	}
	
	/* Test ob PI(); mit den richtigen Parametern aufgerufen wurde,
	 * mittels andReturn(); wird angegeben, welchen Wert die nicht implementierte Methode
	 * zurueckgibt.
	 * Per assertEquals wird der Rueckgabewert ueberprueft.  
	 * -> Fail, falscher Rueckgabewert*/
	@Test
	public void unexpectedValuePi(){
		
		expect(mock.Pi(100)).andReturn((double)3.14);
		replay(mock);
		assertEquals(3.1, piImp.returnPI(100,mock), 0);
		verify(mock);
	
	}

	/* Test ob PI(); mit den richtigen Parametern aufgerufen wurde,
	 * mittels andReturn(); wird angegeben, welchen Wert die nicht implementierte Methode
	 * zurueckgibt.
	 * Per assertEquals wird der Rueckgabewert ueberprueft.  
	 * -> Fail, falscher Parameter*/
	@Test
	public void unexpectedParameterPi(){
		
		expect(mock.Pi(100)).andReturn((double)3.14);
		replay(mock);
		assertEquals(3.14, piImp.returnPI(1000,mock), 0);
		verify(mock);
	
	}
}
